@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Fatten;
 
 our $DATE = '2015-05-16'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -111,7 +111,7 @@ sub munge_module {
         $munged++;
         $self->{_mods} //= {};
         $content =~ s/(^#\s*FATTENED_MODULES\s*$)/
-            "our \@FATTENED_MODULES = \@{" . dmp(sort keys %{$self->{_mods}}) . "}; $1"/em;
+            "our \@FATTENED_MODULES = \@{" . dmp([sort keys %{$self->{_mods}}]) . "}; $1"/em;
     }
 
     if ($content =~ /^#\s*FATTENED_DISTS\s*$/m) {
@@ -129,7 +129,7 @@ sub munge_module {
             }
         }
         $content =~ s/(^#\s*FATTENED_DISTS\s*$)/
-            "our \@FATTENED_DISTS = \@{" . dmp(sort keys %{$self->{_dists}}) . "}; $1"/em;
+            "our \@FATTENED_DISTS = \@{" . dmp([sort keys %{$self->{_dists}}]) . "}; $1"/em;
     }
 
     if ($munged) {
@@ -153,7 +153,7 @@ Dist::Zilla::Plugin::Fatten - Fatpack scripts during build using 'fatten'
 
 =head1 VERSION
 
-This document describes version 0.02 of Dist::Zilla::Plugin::Fatten (from Perl distribution Dist-Zilla-Plugin-Fatten), released on 2015-05-16.
+This document describes version 0.03 of Dist::Zilla::Plugin::Fatten (from Perl distribution Dist-Zilla-Plugin-Fatten), released on 2015-05-16.
 
 =head1 SYNOPSIS
 
